Assumptions class

All symbolic objects have assumption attributes that can be accessed via .is<AssumptionName> attribute.

Assumptions determine certain properties of symbolic objects and can have 3 possible values: true, false, null. true is returned if the object has the property and false is returned if it does not or cannot (i.e. does not make sense).

When the property cannot be determined (or when a method is not implemented) null will be returned. For example, a generic symbol, x, may or may not be positive so a value of null is returned for x.isPositive.

By default, all symbolic values are in the largest set in the given context without specifying the property. For example, a symbol that has a property being integer, is also real, complex, etc.

Constructors

Assumptions({bool? commutative, bool? complex, bool? imaginary, bool? real, bool? extendedReal, bool? integer, bool? nonInteger, bool? odd, bool? even, bool? prime, bool? composite, bool? zero, bool? nonzero, bool? rational, bool? algebraic, bool? transcendental, bool? irrational, bool? finite, bool? infinite, bool? negative, bool? nonNegative, bool? positive, bool? nonPositive, bool? extendedNegative, bool? extendedNonNegative, bool? extendedPositive, bool? extendedNonPositive, bool? extendedNonzero, bool? hermitian, bool? antiHermitian})
const

Properties

algebraic bool?
object can only have values from the set of algebraic numbers.
final
antiHermitian bool?
object belongs to the field of anti-Hermitian operators.
final
commutative bool?
object commutes with any other object with respect to multiplication operation.
final
complex bool?
object can have only values from the set of complex numbers.
final
composite bool?
object is a positive integer that has at least one positive divisor other than 1 or the number itself.
final
even bool?
object can only have values from the set of even integers.
final
extendedNegative bool?
As negative, but also including -oo.
final
extendedNonNegative bool?
As nonNegative, but also including oo.
final
extendedNonPositive bool?
As nonPositive, but also including -oo.
final
extendedNonzero bool?
As nonzero, but also including oo and -oo.
final
extendedPositive bool?
As positive, but also including oo.
final
extendedReal bool?
object can only have values from the set of real numbers, oo, and -oo.
final
finite bool?
Object absolute value is bounded.
final
hashCode int
The hash code for this object.
no setteroverride
hermitian bool?
object belongs to the field of Hermitian operators.
final
imaginary bool?
object value is a number that can be written as a real number multiplied by the imaginary unit I.
final
infinite bool?
Object absolute value is arbitrarily large.
final
integer bool?
object can only have values from the set of integers.
final
irrational bool?
object value cannot be represented exactly as a rational number.
final
negative bool?
object can have only negative values.
final
nonInteger bool?
object can only have values from the set of real numbers excluding the set of integers.
final
nonNegative bool?
object can have only non-negative values.
final
nonPositive bool?
object can have only non-positive values.
final
nonzero bool?
object is a real number that is not zero.
final
odd bool?
object can only have values from the set of odd integers.
final
positive bool?
object can have only positive values.
final
prime bool?
object is a natural number greater than 1 that has no positive divisors other than 1 and itself.
final
rational bool?
object can only have values from the set of rationals.
final
real bool?
object can only have values from the set of real numbers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transcendental bool?
object can only have values from the set of transcendental numbers.
final
zero bool?
object has the value of 0.
final

Methods

copy() Assumptions
copyWith({bool? commutative, bool? complex, bool? imaginary, bool? real, bool? extendedReal, bool? integer, bool? nonInteger, bool? odd, bool? even, bool? prime, bool? composite, bool? zero, bool? nonzero, bool? rational, bool? algebraic, bool? transcendental, bool? irrational, bool? finite, bool? infinite, bool? negative, bool? nonNegative, bool? positive, bool? nonPositive, bool? extendedNegative, bool? extendedNonNegative, bool? extendedPositive, bool? extendedNonPositive, bool? extendedNonzero, bool? hermitian, bool? antiHermitian}) Assumptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLogicMap() Map<Logic, bool?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override