composite property
object is a positive integer that has at least one positive divisor other than 1 or the number itself.
Implementation
final bool? composite;
object is a positive integer that has at least one positive divisor other than 1 or the number itself.
final bool? composite;