imaginary property

bool? imaginary
final

object value is a number that can be written as a real number multiplied by the imaginary unit I.

See https://en.wikipedia.org/wiki/Imaginary_number.

Please note that 0 is not considered to be an imaginary number.

Implementation

final bool? imaginary;