nonInteger property
object can only have values from the set of real numbers excluding the set of integers.
Implementation
final bool? nonInteger;
object can only have values from the set of real numbers excluding the set of integers.
final bool? nonInteger;