Basic class

Implementers

Constructors

Basic(List<Basic> args)

Properties

args List<Basic>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

freeSymbols() Set<Basic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subs(Object substitutions, [bool simultaneous = false]) Basic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited