core/facts library

Classes

FactKB
A simple propositional knowledge base relying on compiled inference rules.
FactRules
Rules that describe how to deduce facts in logic space
Prover
ai - prover of logic rules

Extensions

LogicBoolSort on (Logic, bool)

Functions

applyBetaToAlphaRoute(DefaultMap<Logic, Set<Logic>> alphaImplications, List<(Logic, Logic)> betaRules) Map<Logic, (Set<Logic>, List<int>)>
apply additional beta-rules (And conditions) to already-built alpha implication tables
deduceAlphaImplications(List<(Logic, Logic)> implications) DefaultMap<Logic, Set<Logic>>
deduce all implications
generateFactRules() FactRules
Generate the default assumption rules
rules2Prereq(DefaultMap<(Logic, bool), Set<(Logic, bool)>> rules) DefaultMap<Logic, Set<Logic>>
build prerequisites table from rules
transitiveClosure(List<(Logic, Logic)> implications) Set<(Logic, Logic)>
Computes the transitive closure of a list of implications

Exceptions / Errors

InconsistentAssumptions<K, V>