FactKB class

A simple propositional knowledge base relying on compiled inference rules.

Implementers

Constructors

FactKB(FactRules rules)

Properties

hashCode int
The hash code for this object.
no setterinherited
rules FactRules
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deduceAllFacts(Map<Logic, bool?> facts) → void
Update the KB with all the implications of a list of facts.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<Logic, bool?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) bool?
operator []=(Logic key, bool value) → void