InconsistentAssumptions<K, V> class

Implemented types

Constructors

InconsistentAssumptions(FactKB kb, K fact, V value)

Properties

fact → K
final
hashCode int
The hash code for this object.
no setterinherited
kb FactKB
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → V
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited