And class

Inheritance

Properties

args List<Logic>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(Logic other) int
Compares this object to another object.
inherited
expand() Logic
(a|b|...) & c == (a&c) | (b&c) | ...
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator <(Logic other) bool
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator >(Logic other) bool
inherited

Static Methods

flatten(List<Logic> args) List<Logic>
fromList(List<Logic> args) Logic