Logic class sealed

Logical expression

Implemented types
Implementers

Constructors

Logic.fromString(String text)
Logic from string with space around & and | but none after !.
factory

Properties

args List<Logic>
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(Logic other) int
Compares this object to another object.
override
expand() Logic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator <(Logic other) bool
operator ==(Object other) bool
The equality operator.
override
operator >(Logic other) bool