LogicAtom class

Inheritance

Constructors

LogicAtom(String name)

Properties

args List<Logic>
finalinherited
hashCode int
The hash code for this object.
no setteroverride
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(Logic other) int
Compares this object to another object.
override
expand() Logic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator <(Logic other) bool
inherited
operator ==(Object other) bool
The equality operator.
override
operator >(Logic other) bool
inherited