Symbol class

Inheritance
Implementers

Constructors

Symbol(String name, {Assumptions assumptions = const Assumptions()})
factory

Properties

args List<Basic>
getter/setter pairinherited
assumptions0 Assumptions
latefinal
assumptionsKB StdFactKB
latefinal
hashCode int
The hash code for this object.
no setterinherited
name String
final
originalAssumptions Assumptions
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

freeSymbols() Set<Basic>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subs(Object substitutions, [bool simultaneous = false]) Basic
inherited
toString() String
A string representation of this object.
inherited

Operators

operator %(Basic other) Basic
inherited
operator *(Basic other) Basic
inherited
operator +(Basic other) Basic
inherited
operator -(Basic other) Basic
inherited
operator /(Basic other) Basic
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator ^(Basic other) Basic
inherited
operator unary-() Basic
inherited
operator ~/(Basic other) Basic
inherited