StdFactKB class

A FactKB specialized for the built-in rules

This is the only kind of FactKB that Basic objects should use.

Inheritance

Constructors

StdFactKB([Assumptions? facts])

Properties

hashCode int
The hash code for this object.
no setterinherited
rules FactRules
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deduceAllFacts(Map<Logic, bool?> facts) → void
Update the KB with all the implications of a list of facts.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAssumptions() Assumptions
Returns the derived assumptions after all facts have been deduced.
toMap() Map<Logic, bool?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) bool?
inherited
operator []=(Logic key, bool value) → void
inherited