FactKB class
A simple propositional knowledge base relying on compiled inference rules.
- Implementers
Properties
Methods
-
deduceAllFacts(
Map< Logic, bool?> facts) → void - Update the KB with all the implications of a list of facts.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< Logic, bool?> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Object? key) → bool? -
operator []=(
Logic key, bool value) → void