Dummy class
- Inheritance
-
- Object
- Basic
- Expr
- AtomicExpr
- Symbol
- Dummy
Constructors
- Dummy(String? name, int? dummyIndex, {Assumptions assumptions = const Assumptions()})
Properties
-
args
↔ List<
Basic> -
getter/setter pairinherited
- assumptions0 ↔ Assumptions
-
latefinalinherited
- assumptionsKB ↔ StdFactKB
-
latefinalinherited
- dummyIndex ↔ int
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
finalinherited
- originalAssumptions ↔ Assumptions
-
latefinalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
freeSymbols(
) → Set< Basic> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subs(
Object substitutions, [bool simultaneous = false]) → Basic -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator %(
Basic other) → Basic -
inherited
-
operator *(
Basic other) → Basic -
inherited
-
operator +(
Basic other) → Basic -
inherited
-
operator -(
Basic other) → Basic -
inherited
-
operator /(
Basic other) → Basic -
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator ^(
Basic other) → Basic -
inherited
-
operator unary-(
) → Basic -
inherited
-
operator ~/(
Basic other) → Basic -
inherited